;;; helm-core-pkg.el --- define helm-core for package.el

(define-package "helm-core" "2.0"
  "Development files for Helm"
  '((emacs "24.3")
    (async "1.9"))
  :url "https://emacs-helm.github.io/helm/")

;; Local Variables:
;; no-byte-compile: t
;; End:
